<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:optim="http://www.ibm.com/optim/audit/v11.3.0.0"
	xmlns:optimreport="http://www.ibm.com/optim/report/v11.3.0.0"
	xmlns:optimcommon="http://www.ibm.com/optim/common/v11.3.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

	<xsl:import href="CommonTemplates.xsl"/>
	
	<xsl:output method="html" indent="yes" version="4.0"
		doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd" />

	<!-- Extended Objects Main Template -->
	<xsl:template match="optimreport:extendedObjectTypes">
	<xsl:if test="count(optimcommon:extendedObjectType) &gt; 0">
		<xsl:call-template name="anchorSetup">
			<xsl:with-param name="name">extobjs</xsl:with-param>
		</xsl:call-template>
		<!-- Extended Objects Banner -->
		<xsl:call-template name="titleBar">
			<xsl:with-param name="name">Extended Objects</xsl:with-param>
			<xsl:with-param name="containerId">extobjs_container</xsl:with-param>
			<xsl:with-param name="containerClass">extobjs_container_class</xsl:with-param>
			<xsl:with-param name="anchor">extobjs</xsl:with-param>
			<xsl:with-param name="closeByDefault">true</xsl:with-param>
		</xsl:call-template>
		
		<!-- Extended Objects Contents -->
		<div id="extobjs_container" class="section_container extobjs_container_class" inAllAction="true" style="display:none">
			<div class="extobjs_innerContainer">
				<xsl:call-template name="extendedTable">
					<xsl:with-param name="num" select="count(optimcommon:extendedObjectType)" />
				</xsl:call-template>
			</div>
		</div>
	</xsl:if>
	</xsl:template>
	
	<!-- This template attempts to determine if the Extended Table has more than 5 rows -->
	<!-- then split the table into 2, utilizing the width of the web page. 				-->
	<!-- Parameter: number, the total count of all extended object types.				-->
	<xsl:template name="extendedTable">
		<xsl:param name="num"/>
		
		<!-- If the number of extended object rows is greater than 5, we split -->
		<xsl:choose>
			<xsl:when test="$num &lt; 5">
				<table class="extobjs_table">
					<xsl:call-template name="extendedTableTitle" />
					<xsl:for-each select="optimcommon:extendedObjectType">
						<xsl:call-template name="extendedTableRow" />
					</xsl:for-each>
				</table>
			</xsl:when>
			<xsl:otherwise>
				<table class="extobjs_table">
					<xsl:call-template name="extendedTableTitle" />
					<xsl:for-each select="optimcommon:extendedObjectType">
						<xsl:if test="position() &lt;= ceiling($num div 2) ">
							<xsl:call-template name="extendedTableRow" />
						</xsl:if>
					</xsl:for-each>
				</table>
				<table class="extobjs_table">
					<xsl:call-template name="extendedTableTitle" />
					<xsl:for-each select="optimcommon:extendedObjectType">
						<xsl:if test="position() &gt; ceiling($num div 2) ">
							<xsl:call-template name="extendedTableRow" />
						</xsl:if>
					</xsl:for-each>
				</table>
			</xsl:otherwise>		
		</xsl:choose>
	</xsl:template>
	
	<!-- This template is the table header, utilized twice if we split the table in two. -->
	<xsl:template name="extendedTableTitle">
		<tr isTitle="yes">
			<th>
				<center>
						<xsl:text>Type</xsl:text>
				</center>
			</th>
			<td>
				<center>
						<xsl:text>Extracted</xsl:text>
				</center>
			</td>
			<td>
				<center>
						<xsl:text>Failed</xsl:text>
				</center>
			</td>
		</tr>
	</xsl:template>
	
	<!-- This template applies to the data within the rows. -->
	<xsl:template name="extendedTableRow">
		<tr class="rightAlign">
			<th>
				<xsl:call-template name="stringCheck">
					<xsl:with-param name="value" select="@type"/>
				</xsl:call-template>
			</th>
			<td>
				<xsl:call-template name="numberFormat">
					<xsl:with-param name="number" select="@extractedCount"/>
					<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
				</xsl:call-template>
			</td>
			<td>
				<xsl:call-template name="numberFormat">
					<xsl:with-param name="number" select="@failedCount"/>
					<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
				</xsl:call-template>
			</td>
		</tr>
	</xsl:template>

</xsl:stylesheet>

